secure_dealloc_aligned

Function secure_dealloc_aligned 

pub unsafe fn secure_dealloc_aligned(
    ptr: *mut u8,
    size: usize,
    alignment: usize,
)
Secure memory deallocation with custom alignment

Safety

  • ptr must be a valid pointer returned by a previous allocation
  • size must be the same size that was used for the original allocation
  • alignment must be the same alignment that was used for the original allocation
  • The memory must not be accessed after this function returns