Input validation and sanitization
This module provides comprehensive input validation functions to ensure that all inputs to cryptographic operations are safe and valid.
Structs
- Input
Validator - Input validator
- Validation
Config - Input validation configuration
Functions
- get_
input_ validator - Get the global input validator
- set_
input_ validator - Set the global input validator
- validate_
associated_ data - Validate associated data using the global validator
- validate_
ciphertext - Validate ciphertext using the global validator
- validate_
key - Convenience functions for global validation Validate a key using the global validator
- validate_
key_ size - Validate key size using the global validator
- validate_
nonce - Validate a nonce using the global validator
- validate_
nonce_ size - Validate nonce size using the global validator
- validate_
plaintext - Validate plaintext using the global validator