AeadMetadata

Struct AeadMetadata 

pub struct AeadMetadata {
    pub algorithm: Algorithm,
    pub key_size: usize,
    pub nonce_size: usize,
    pub tag_size: usize,
    pub security_level: u32,
    pub name: &'static str,
    pub description: &'static str,
    pub supports_semantic_decrypt: bool,
}
Metadata for AEAD algorithms

Fields

algorithm: Algorithm

The algorithm identifier

key_size: usize

Key size in bytes

nonce_size: usize

Nonce size in bytes

tag_size: usize

Authentication tag size in bytes

security_level: u32

Security level (1, 3, 4, 5)

name: &'static str

Human-readable algorithm name

description: &'static str

Algorithm description

supports_semantic_decrypt: bool

Whether the canonical lib-q-aead / leaf types for this algorithm implement lib_q_core::AeadDecryptSemantic (Layer B semantic decrypt).

This reflects the algorithm capability table, not runtime guarantees for arbitrary dyn AeadWithMetadata test doubles; those may override AeadWithMetadata::supports_semantic_decrypt.

Implementations

Source

impl AeadMetadata

pub const fn new( algorithm: Algorithm, key_size: usize, nonce_size: usize, tag_size: usize, security_level: u32, name: &'static str, description: &'static str, supports_semantic_decrypt: bool, ) -> Self

Create new metadata.

supports_semantic_decrypt is explicit per static table row (rather than inferred) so capability stays auditable next to the numeric sizes in get_metadata.

pub fn performance_tier(&self) -> PerformanceTier

Get the performance tier for this algorithm

pub fn is_suitable_for_security_level(&self, required_level: u32) -> bool

Check if this algorithm is suitable for the given security level

pub fn total_overhead(&self) -> usize

Get the total overhead (nonce + tag) for this algorithm

pub fn validate_key_size(&self, key_size: usize) -> bool

Validate key size

pub fn validate_nonce_size(&self, nonce_size: usize) -> bool

Validate nonce size

pub fn validate_tag_size(&self, tag_size: usize) -> bool

Validate tag size