pub unsafe fn secure_dealloc_aligned(
ptr: *mut u8,
size: usize,
alignment: usize,
)Expand description
Secure memory deallocation with custom alignment
Safety
ptrmust be a valid pointer returned by a previous allocationsizemust be the same size that was used for the original allocationalignmentmust be the same alignment that was used for the original allocation- The memory must not be accessed after this function returns